@@ -23,11 +23,10 @@ use headers::*;
 use mime_guess::from_path;
 
 use super::{ChunkedState, FileChunk};
-use crate::http::header;
-use crate::http::header::{CONTENT_DISPOSITION, CONTENT_ENCODING};
+use crate::http::errors::StatusError;
+use crate::http::header::{self, CONTENT_DISPOSITION, CONTENT_ENCODING};
 use crate::http::{HttpRange, Request, Response, StatusCode};
-use crate::Depot;
-use crate::Writer;
+use crate::{Depot, Error, Result, Writer};
 
 const CHUNK_SIZE: u64 = 1024 * 1024;
 
@@ -110,8 +109,19 @@ impl NamedFileBuilder {
         self.flags.set(Flags::ETAG, value);
         self
     }
+    /// Build a new `NamedFile` and send it.
+    pub async fn send(self, req: &mut Request, res: &mut Response) {
+        if !self.path.exists() {
+            res.set_status_error(StatusError::not_found());
+        } else {
+            match self.build().await {
+                Ok(file) => file.send(req, res).await,
+                Err(_) => res.set_status_error(StatusError::internal_server_error()),
+            }
+        }
+    }
     /// Build a new `NamedFile`.
-    pub async fn build(self) -> crate::Result<NamedFile> {
+    pub async fn build(self) -> Result<NamedFile> {
         let NamedFileBuilder {
             path,
             content_type,
@@ -123,7 +133,7 @@ impl NamedFileBuilder {
             flags,
         } = self;
 
-        let file = File::open(&path).await.map_err(crate::Error::new)?;
+        let file = File::open(&path).await?;
         let content_type = content_type.unwrap_or_else(|| {
             let ct = from_path(&path).first_or_octet_stream();
             let ftype = ct.type_();
@@ -162,11 +172,11 @@ impl NamedFileBuilder {
                 }
             })
         });
-        let content_disposition = content_disposition.parse::<HeaderValue>().map_err(crate::Error::new)?;
-        let metadata = file.metadata().await.map_err(crate::Error::new)?;
+        let content_disposition = content_disposition.parse::<HeaderValue>().map_err(Error::other)?;
+        let metadata = file.metadata().await?;
         let modified = metadata.modified().ok();
         let content_encoding = match content_encoding {
-            Some(content_encoding) => Some(content_encoding.parse::<HeaderValue>().map_err(crate::Error::new)?),
+            Some(content_encoding) => Some(content_encoding.parse::<HeaderValue>().map_err(Error::other)?),
             None => None,
         };
 
@@ -211,10 +221,23 @@ impl NamedFile {
     /// # }
     /// ```
     #[inline]
-    pub async fn open(path: impl Into<PathBuf>) -> crate::Result<NamedFile> {
+    pub async fn open(path: impl Into<PathBuf>) -> Result<NamedFile> {
         Self::builder(path).build().await
     }
 
+    /// Attempts to send a file. If file not exists, not found error will occur.
+    pub async fn send_file(path: impl Into<PathBuf>, req: &mut Request, res: &mut Response) {
+        let path = path.into();
+        if !path.exists() {
+            res.set_status_error(StatusError::not_found());
+        } else {
+            match Self::builder(path).build().await {
+                Ok(file) => file.send(req, res).await,
+                Err(_) => res.set_status_error(StatusError::internal_server_error()),
+            }
+        }
+    }
+
     /// Returns reference to the underlying `File` object.
     #[inline]
     pub fn file(&self) -> &File {
@@ -342,11 +365,7 @@ impl NamedFile {
         self.flags.set(Flags::LAST_MODIFIED, value);
         self
     }
-}
-
-#[async_trait]
-impl Writer for NamedFile {
-    async fn write(mut self, req: &mut Request, _depot: &mut Depot, res: &mut Response) {
+    async fn send(self, req: &mut Request, res: &mut Response) {
         let etag = if self.flags.contains(Flags::ETAG) {
             self.etag()
         } else {
@@ -460,6 +479,13 @@ impl Writer for NamedFile {
     }
 }
 
+#[async_trait]
+impl Writer for NamedFile {
+    async fn write(mut self, req: &mut Request, _depot: &mut Depot, res: &mut Response) {
+        self.send(req, res).await;
+    }
+}
+
 impl Deref for NamedFile {
     type Target = File;
 
